Dom

Struct Dom 

pub struct Dom<Message = (), Command = (), Key = ()> {
    pub attributes: Vec<Attr>,
    pub events: Vec<Event<Message>>,
    pub children: Vec<Dom<Message, Command, Key>>,
    /* private fields */
}
A node in the DOM.

Fields

attributes: Vec<Attr>

Attributes on this node.

events: Vec<Event<Message>>

Event handlers associated with this node.

children: Vec<Dom<Message, Command, Key>>

Children of this node.

Implementations

Source

impl<Message, Command, Key> Dom<Message, Command, Key>

pub fn elem(element: &'static str) -> Self

Create a new DOM element node.

pub fn text(value: impl Into<String>) -> Self

Create a new DOM text node.

pub fn component( msg: Message, create: fn(Dispatcher<Message, Command>) -> Box<dyn Component<Message>>, ) -> Self

Create a component.

pub fn key(self, key: impl Into<Key>) -> Self

Add an key to this DOM element.

pub unsafe fn inner_html(self, value: impl Into<String>) -> Self

Set innerHtml on this node. Use with caution as this can be used as an attack vector to execute arbitrary code in the client’s browser.

pub fn attr(self, name: &'static str, value: impl Into<String>) -> Self

Add an attribute to this DOM element.

pub fn event(self, trigger: &'static str, msg: Message) -> Self

Add an event listener to this DOM element.

pub fn on(self, trigger: &'static str, handler: Handler<Message>) -> Self

Add an event listener to this DOM element.

pub fn onchange(self, handler: fn(String) -> Option<Message>) -> Self

Add a change event listener to this DOM element.

pub fn oninput(self, handler: fn(InputEvent) -> Option<Message>) -> Self

Add an input event listener to this DOM element.

pub fn push(self, child: impl Into<Dom<Message, Command, Key>>) -> Self

Append the given element as a child on this DOM element.

pub fn extend( self, iter: impl IntoIterator<Item = Dom<Message, Command, Key>>, ) -> Self

Append the elements returned by the given iterator as children on this DOM element.