pub enum Handler<Message> {
Msg(Message),
Event(fn(Event) -> Option<Message>),
MsgEvent(Message, fn(Message, Event) -> Option<Message>),
InputValue(fn(String) -> Option<Message>),
InputEvent(fn(InputEvent) -> Option<Message>),
}Expand description
A DOM event handler.
Variants
Msg(Message)
The message that will result from the event this handler is attached to.
Event(fn(Event) -> Option<Message>)
A function that will convert a web_sys::Event event to a Message.
MsgEvent(Message, fn(Message, Event) -> Option<Message>)
A function that will convert a web_sys::Event event to a Message.
This variation allows passing data to the event handler via a Message.
InputValue(fn(String) -> Option<Message>)
A function that will convert a String from an input element into a Message.
InputEvent(fn(InputEvent) -> Option<Message>)
A function that will convert a web_sys::InputEvent event to a Message.