pub struct Dom<Message = (), Command = (), Key = ()> {
pub attributes: Vec<Attr>,
pub events: Vec<Event<Message>>,
pub children: Vec<Dom<Message, Command, Key>>,
/* private fields */
}Expand description
A node in the DOM.
Fields
attributes: Vec<Attr>Attributes on this node.
events: Vec<Event<Message>>Event handlers associated with this node.
children: Vec<Dom<Message, Command, Key>>Children of this node.
Implementations
Sourceimpl<Message, Command, Key> Dom<Message, Command, Key>
impl<Message, Command, Key> Dom<Message, Command, Key>
Sourcepub fn component(
msg: Message,
create: fn(Dispatcher<Message, Command>) -> Box<dyn Component<Message>>,
) -> Self
pub fn component( msg: Message, create: fn(Dispatcher<Message, Command>) -> Box<dyn Component<Message>>, ) -> Self
Create a component.
Sourcepub unsafe fn inner_html(self, value: impl Into<String>) -> Self
pub unsafe fn inner_html(self, value: impl Into<String>) -> Self
Set innerHtml on this node. Use with caution as this can be used as an attack vector to execute arbitrary code in the client’s browser.
Sourcepub fn attr(self, name: &'static str, value: impl Into<String>) -> Self
pub fn attr(self, name: &'static str, value: impl Into<String>) -> Self
Add an attribute to this DOM element.
Sourcepub fn event(self, trigger: &'static str, msg: Message) -> Self
pub fn event(self, trigger: &'static str, msg: Message) -> Self
Add an event listener to this DOM element.
Sourcepub fn on(self, trigger: &'static str, handler: Handler<Message>) -> Self
pub fn on(self, trigger: &'static str, handler: Handler<Message>) -> Self
Add an event listener to this DOM element.
Sourcepub fn onchange(self, handler: fn(String) -> Option<Message>) -> Self
pub fn onchange(self, handler: fn(String) -> Option<Message>) -> Self
Add a change event listener to this DOM element.
Sourcepub fn oninput(self, handler: fn(InputEvent) -> Option<Message>) -> Self
pub fn oninput(self, handler: fn(InputEvent) -> Option<Message>) -> Self
Add an input event listener to this DOM element.
Sourcepub fn push(self, child: impl Into<Dom<Message, Command, Key>>) -> Self
pub fn push(self, child: impl Into<Dom<Message, Command, Key>>) -> Self
Append the given element as a child on this DOM element.
Sourcepub fn extend(
self,
iter: impl IntoIterator<Item = Dom<Message, Command, Key>>,
) -> Self
pub fn extend( self, iter: impl IntoIterator<Item = Dom<Message, Command, Key>>, ) -> Self
Append the elements returned by the given iterator as children on this DOM element.